<?php

/**
  Name: Z-Payment
  Class: wpi_zpayment
  Internal Slug: wpi_zpayment
  JS Slug: wpi_zpayment
  Version: 1.0
  Description: Provides Z-Payment gateway. No recurring payments support.
 */
class wpi_zpayment extends wpi_gateway_base {

    /**
     * Construct
     */
    public function __construct() {
        parent::__construct();

        $this->options = array(
            'name' => 'Z-Payment',
            'allow' => '',
            'default_option' => '',
            'settings' => array(
                'shop_id' => array(
                    'label' => __("Shop ID", WPI),
                    'value' => ''
                ),
                'secret_key' => array(
                    'label' => __("Merchant key", WPI),
                    'value' => ''
                ),
                'init_pass' => array(
                    'label' => __("Пароль инициализации", WPI),
                    'value' => ''
                ),
                'ipn' => array(
                    'label' => __("Result URL", WPI),
                    'type' => "readonly",
                    'description' => __("Use this URL as Result URL in Z-Payment shop settings to get notified once payments made.", WPI)
                )
            )
        );

        //** Fields for front-end. */
        $this->front_end_fields = array(
            'customer_information' => array(
                'first_name' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'first_name',
                    'label' => __('First Name', WPI)
                ),
                'last_name' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'last_name',
                    'label' => __('Last Name', WPI)
                ),
                'user_email' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'email_address',
                    'label' => __('Email Address', WPI)
                ),
                'phonenumber' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'phonenumber',
                    'label' => __('Phone', WPI)
                ),
                'streetaddress' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'address1',
                    'label' => __('Address', WPI)
                ),
                'city' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'city',
                    'label' => __('City', WPI)
                ),
                'state' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'state',
                    'label' => __('State/Province', WPI)
                ),
                'zip' => array(
                    'type' => 'text',
                    'class' => 'text-input',
                    'name' => 'zip',
                    'label' => __('Zip/Postal Code', WPI)
                )
            )
        );

        $this->options['settings']['ipn']['value'] = admin_url('admin-ajax.php?action=wpi_gateway_server_callback&type=wpi_zpayment');

    }

    /**
     * Show settings for RB. Nothing in case of zpayment
     * @param type $invoice
     */
    function recurring_settings( $invoice ) {
    ?>
      <h4><?php _e( 'zpayment Recurring Billing', WPI ); ?></h4>
      <p><?php _e( 'Currently zpayment gateway does not support Recurring Billing', WPI ); ?></p>
      <?php
    }

  /**
   * Fields renderer
   * @param type $invoice
   */
  function wpi_payment_fields($invoice) {

    $this->front_end_fields = apply_filters('wpi_crm_custom_fields', $this->front_end_fields, 'crm_data');

    if (!empty($this->front_end_fields)) {
      //** For each section */
      foreach ($this->front_end_fields as $key => $value) {
        //** If section is not empty */
        if (!empty($this->front_end_fields[$key])) {
          $html = '';
          ob_start();
          ?>
          <ul class="wpi_checkout_block">
            <li class="section_title"><?php _e(ucwords(str_replace('_', ' ', $key)), WPI); ?></li>
            <?php
            $html = ob_get_clean();
            echo $html;
            //** For each field */
            foreach ($value as $field_slug => $field_data) {
              //** Change field properties if we need */
              $field_data = apply_filters('wpi_payment_form_styles', $field_data, $field_slug, 'wpi_zpayment');
              $html = '';

              ob_start();

              switch ($field_data['type']) {
                case self::TEXT_INPUT_TYPE:
                  ?>

                  <li class="wpi_checkout_row">
                    <div class="control-group">
                      <label class="control-label" for="<?php echo esc_attr($field_slug); ?>"><?php _e($field_data['label'], WPI); ?></label>
                      <div class="controls">
                        <input type="<?php echo esc_attr($field_data['type']); ?>" class="<?php echo esc_attr($field_data['class']); ?>"  name="<?php echo esc_attr($field_data['name']); ?>" value="<?php echo!empty($invoice['user_data'][$field_slug]) ? $invoice['user_data'][$field_slug] : ''; ?>" />
                      </div>
                    </div>
                  </li>

                  <?php
                  $html = ob_get_clean();

                  break;

                case self::SELECT_INPUT_TYPE:
                  ?>

                  <li class="wpi_checkout_row">
                    <label for="<?php echo esc_attr($field_slug); ?>"><?php _e($field_data['label'], WPI); ?></label>
                    <?php echo WPI_UI::select("name={$field_data['name']}&values={$field_data['values']}&id={$field_slug}&class={$field_data['class']}"); ?>
                  </li>

                  <?php
                  $html = ob_get_clean();

                  break;

                default:
                  break;
              }

              echo $html;
            }
            echo '</ul>';
          }
        }
      }
    }

    /**
     * Merchant CB handler
     */
    function server_callback() {

        if ( empty( $_POST ) ) die(__('Direct access not allowed', WPI));
		if($_POST['LMI_PREREQUEST']==1) {
		    echo 'YES';
		    die();
		} 
		$LMI_PAYEE_PURSE = $_POST['LMI_PAYEE_PURSE'];
		$LMI_PAYMENT_AMOUNT = $_POST['LMI_PAYMENT_AMOUNT'];
		$LMI_PAYMENT_NO = $_POST['LMI_PAYMENT_NO'];
		$LMI_SYS_TRANS_NO = $_POST['LMI_SYS_TRANS_NO'];
		$LMI_SECRET_KEY = $_POST['LMI_SECRET_KEY'];
		$LMI_MODE = $_POST['LMI_MODE'];
		$LMI_SYS_INVS_NO = $_POST['LMI_SYS_INVS_NO'];
		$LMI_SYS_TRANS_DATE = $_POST['LMI_SYS_TRANS_DATE'];
		$LMI_PAYER_PURSE = $_POST['LMI_PAYER_PURSE'];
		$LMI_PAYER_WM = $_POST['LMI_PAYER_WM'];
		$LMI_HASH = $_POST['LMI_HASH'];
		
		$err=FALSE;

		if(!$LMI_PAYMENT_NO) {
			die("ERROR: LMI_PAYMENT_NO!\n");
		}
				
        $invoice = new WPI_Invoice();
		if(!$invoice) {
			die("ERROR: EMPTY INVOICE!\n");
		}
		
		
        $invoice->load_invoice("id={$LMI_PAYMENT_NO}");
		$shop_id=$invoice->data['billing'][$this->type]['settings']['shop_id']['value'];
		$shopSecret=$invoice->data['billing'][$this->type]['settings']['secret_key']['value'];
		
		
		$amount=number_format( (float)$invoice->data['net'], 2, '.', '' );
		if($amount!=$LMI_PAYMENT_AMOUNT){
		    die();
		}
		if($shop_id!=$LMI_PAYEE_PURSE){
		   die();
		}
		

		if(isset($LMI_SECRET_KEY)) {
            if($LMI_SECRET_KEY!=$shopSecret) {
                $err = TRUE;
		    }
	    } else {
        $CalcHash = md5($LMI_PAYEE_PURSE.$LMI_PAYMENT_AMOUNT.$LMI_PAYMENT_NO.$LMI_MODE.$LMI_SYS_INVS_NO.$LMI_SYS_TRANS_NO.$LMI_SYS_TRANS_DATE.$shopSecret.$LMI_PAYER_PURSE.$LMI_PAYER_WM);
		    if($LMI_HASH != strtoupper($CalcHash)) {
                $err = TRUE;
	        }
        }
		
		if(!$err) {
			$event_note = 'paid via zpayment';
            $event_type   = 'add_payment';
            $invoice->add_entry("attribute=balance&note=$event_note&amount=$amount&type=$event_type");
            $trans_id = sprintf(__("Transaction ID: %s", WPI), $LMI_SYS_TRANS_NO);
            $invoice->add_entry("attribute=invoice&note=$trans_id&type=update");
            $invoice->save_invoice();
            wp_invoice_mark_as_paid( $LMI_PAYMENT_NO, $check = true );
            send_notification( $invoice->data );
			echo 'YES';
		}
		
      
    }

    /**
     * Payment Processor
     */
    function process_payment() {
        global $invoice;

        $crm_data = $_REQUEST['crm_data'];
        $wp_users_id = $invoice['user_data']['ID'];

        //** update user data */
        update_user_meta($wp_users_id, 'last_name', $_REQUEST['last_name']);
        update_user_meta($wp_users_id, 'first_name', $_REQUEST['first_name']);
        update_user_meta($wp_users_id, 'city', $_REQUEST['city']);
        update_user_meta($wp_users_id, 'state', $_REQUEST['state']);
        update_user_meta($wp_users_id, 'zip', $_REQUEST['zip']);
        update_user_meta($wp_users_id, 'streetaddress', $_REQUEST['address1']);
        update_user_meta($wp_users_id, 'phonenumber', $_REQUEST['phonenumber']);
        update_user_meta($wp_users_id, 'country', $_REQUEST['country']);

        if (!empty($crm_data))
            $this->user_meta_updated($crm_data);

        echo json_encode(
            array('success' => 1)
        );
    }

}
?>
